==> phonon-4.5.1.tar.xz: phonon-4.5.1/phonon/experimental/videowidget.cpp <==
/*  This file is part of the KDE project
    Copyright (C) 2008 Matthias Kretz <kretz@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), Nokia Corporation 
    (or its successors, if any) and the KDE Free Qt Foundation, which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public 
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "videowidget.h"
#include "snapshotinterface.h"
#include "videowidget_p.h"

namespace Phonon
{
namespace Experimental
{

VideoWidget::VideoWidget(QWidget *w)
    : Phonon::VideoWidget(w)
{
}

QImage VideoWidget::snapshot() const
{
    K_D(const Phonon::VideoWidget);
    SnapshotInterface *iface = qobject_cast<SnapshotInterface *>(d->m_backendObject);
    if (iface) {
        return iface->snapshot();
    }
    return QImage();
}

} // namespace Experimental
} // namespace Phonon

==> phonon_4.9.0.orig.tar.xz: phonon-4.9.0/phonon/experimental/videowidget.cpp <==
/*  This file is part of the KDE project
    Copyright (C) 2008 Matthias Kretz <kretz@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), Nokia Corporation
    (or its successors, if any) and the KDE Free Qt Foundation, which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.

*/

#include "videowidget.h"
#include "videowidget_p.h"

#include "snapshotinterface.h"

namespace Phonon
{
namespace Experimental
{

VideoWidget::VideoWidget(QWidget *w)
    : Phonon::VideoWidget(w)
{
}

QImage VideoWidget::snapshot() const
{
    P_D(const Phonon::VideoWidget);
    SnapshotInterface *iface = qobject_cast<SnapshotInterface *>(d->m_backendObject);
    if (iface) {
        return iface->snapshot();
    }
    return QImage();
}

} // namespace Experimental
} // namespace Phonon
